<TS version="2.1" language="fa">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">برای ویرایش آدرس یا برچسب راست کلیک کنید</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">یک آدرس جدید بسازید</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp; جدید</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation type="unfinished">آدرس انتخاب شده را در حافظه سیستم ذخیره کنید</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp; ذخیره</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">بستن</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">آدرس انتخاب شده را از لیست پاک کنید</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">آدرس یا برچسب را برای جستجو وارد کنید</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">داده های موجود در برگه فعلی را به یک فایل صادر کنید</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">اینها آدرس های بیت کوین شما برای ارسال پرداخت هستند. همیشه قبل از ارسال سکه، مبلغ و آدرس دریافت کننده را بررسی کنید.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">اینها آدرس های بیت کوین شما برای دریافت هستند. از دکمه "ایجاد آدرس دریافت جدید" در برگه دریافت برای ایجاد آدرس های جدید استفاده کنید.
امضا فقط با آدرس هایی از نوع "میراث" امکان پذیر است.</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Continue</source>
        <translation type="unfinished">ادامه</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished">بازگشت</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">خطا: %1</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1 هنوز به صورت ایمن بیرون نرفته است...</translation>
    </message>
    <message>
        <source>Embedded "%1"</source>
        <translation type="unfinished">تعبیه شده%1</translation>
    </message>
    <message>
        <source>Default system font "%1"</source>
        <translation type="unfinished">فونت پیش فرض سیستم «%1»</translation>
    </message>
    <message>
        <source>Custom…</source>
        <translation type="unfinished">سفارشی...</translation>
    </message>
    <message>
        <source>Enter a Bitcoin address (e.g. %1)</source>
        <translation type="unfinished">آدرس بیت کوین را وارد کنید (به طور مثال %1)</translation>
    </message>
    <message>
        <source>Unroutable</source>
        <translation type="unfinished">غیرقابل برنامه ریزی</translation>
    </message>
    <message>
        <source>Onion</source>
        <comment>network name</comment>
        <extracomment>Name of Tor network in peer info</extracomment>
        <translation type="unfinished">persian</translation>
    </message>
    <message>
        <source>Full Relay</source>
        <extracomment>Peer connection type that relays all network information.</extracomment>
        <translation type="unfinished">رله کامل</translation>
    </message>
    <message>
        <source>Block Relay</source>
        <extracomment>Peer connection type that relays network information about blocks and not transactions or addresses.</extracomment>
        <translation type="unfinished">رله بلوک</translation>
    </message>
    <message>
        <source>Manual</source>
        <extracomment>Peer connection type established manually through one of several methods.</extracomment>
        <translation type="unfinished">دستی </translation>
    </message>
    <message>
        <source>Feeler</source>
        <extracomment>Short-lived peer connection type that tests the aliveness of known addresses.</extracomment>
        <translation type="unfinished">دیده بان</translation>
    </message>
    <message>
        <source>Address Fetch</source>
        <extracomment>Short-lived peer connection type that solicits known addresses from a peer.</extracomment>
        <translation type="unfinished">فهرست نشانی‌ها</translation>
    </message>
    <message>
        <source>%1 d</source>
        <translation type="unfinished">%1 روز قبل</translation>
    </message>
    <message>
        <source>%1 h</source>
        <translation type="unfinished">%1 ساعت قبل</translation>
    </message>
    <message>
        <source>%1 m</source>
        <translation type="unfinished">%1 دقیقه قبل</translation>
    </message>
    <message>
        <source>%1 s</source>
        <translation type="unfinished">%1 ثانیه قبل</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished">هیچ کدام</translation>
    </message>
    <message>
        <source>%1 ms</source>
        <translation type="unfinished">%1 میلی ثانیه</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform>%n second(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform>%n minute(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform>%n hour(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform>%n day(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform>%n week(s)</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation type="unfinished">%1 و %2</translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform>%n year(s)</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 B</source>
        <translation type="unfinished">%1 بایت</translation>
    </message>
    <message>
        <source>%1 kB</source>
        <translation type="unfinished">%1کیلوبایت</translation>
    </message>
    <message>
        <source>%1 MB</source>
        <translation type="unfinished">%1 مگابایت</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation type="unfinished">%1 گیگابایت</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">کیف پول پیش فرض
 </translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">بازبینی</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation type="unfinished">نمایش کلی کیف پول
 </translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">تراکنش</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">تاریخچه تراکنش را باز کن</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">خروج</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">از "درخواست نامه"/ application خارج شو</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">&amp;درباره %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">نمایش اطلاعات درباره %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">درباره Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">نمایش اطلاعات درباره Qt</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation type="unfinished">اصلاح انتخاب ها برای پیکربندی %1</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">کیف پول جدیدی ایجاد کنید
 </translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished">&amp;به حداقل رساندن</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">فعالیت شبکه غیرفعال شد.</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation type="unfinished">پراکسی &lt;b&gt;فعال&lt;/b&gt; شده است: %1</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">ارسال کوین به آدرس بیت کوین</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation type="unfinished">پشتیبان گیری از کیف پول به مکان دیگر
 </translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation type="unfinished">رمز عبور مربوط به رمزگذاریِ کیف پول  را تغییر دهید</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">ارسال</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">دریافت</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet…</source>
        <translation type="unfinished">رمزنگاری کیف پول</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation type="unfinished">کلیدهای خصوصی متعلق به کیف پول شما را رمزگذاری کنید
 </translation>
    </message>
    <message>
        <source>&amp;Backup Wallet…</source>
        <translation type="unfinished">نسخه پشتیبان کیف پول</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase…</source>
        <translation type="unfinished">تغییر عبارت عبور</translation>
    </message>
    <message>
        <source>Sign &amp;message…</source>
        <translation type="unfinished">ثبت &amp;پیام</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation type="unfinished">پیام‌ها را با آدرس بیت‌کوین خود امضا کنید تا مالکیت آن‌ها را اثبات کنید</translation>
    </message>
    <message>
        <source>&amp;Verify message…</source>
        <translation type="unfinished">پیام تایید</translation>
    </message>
    <message>
        <source>&amp;Load PSBT from file…</source>
        <translation type="unfinished">بارگیری PSBT از پرونده</translation>
    </message>
    <message>
        <source>Open &amp;URI…</source>
        <translation type="unfinished">تکثیر نشانی</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">بستن کیف پول</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">ساخت کیف پول</translation>
    </message>
    <message>
        <source>Close All Wallets…</source>
        <translation type="unfinished">بستن همهٔ کیف پول‌ها</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">فایل</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">تنظیمات</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">راهنما</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation type="unfinished">نوار ابزار</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)…</source>
        <translation type="unfinished">درحال همگام‌سازی هدرها (%1%)…</translation>
    </message>
    <message>
        <source>Synchronizing with network…</source>
        <translation type="unfinished">هماهنگ‌سازی با شبکه</translation>
    </message>
    <message>
        <source>Indexing blocks on disk…</source>
        <translation type="unfinished">در حال شماره‌گذاری بلوکها روی دیسک...</translation>
    </message>
    <message>
        <source>Processing blocks on disk…</source>
        <translation type="unfinished">در حال پردازش بلوکها روی دیسک..</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation type="unfinished">نمایش لیست آدرس‌ها و لیبل‌های ارسالی استفاده شده</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation type="unfinished">نمایش لیست آدرس‌ها و لیبل‌های دریافتی استفاده شده</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation type="unfinished">گزینه های خط فرمان</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform>Processed %n block(s) of transaction history.</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">%1 قبل</translation>
    </message>
    <message>
        <source>Catching up…</source>
        <translation type="unfinished">در حال گرفتن..</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation type="unfinished">آخرین بلاک دریافت شده تولید شده در %1 قبل.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation type="unfinished">تراکنش‌های بعد از این تراکنش هنوز در دسترس نیستند.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">خطا</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">هشدار</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">اطلاعات</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">به روز</translation>
    </message>
    <message>
        <source>Load PSBT from &amp;clipboard…</source>
        <translation type="unfinished">بارگیری PSBT از &amp;clipboard…</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation type="unfinished">پنجره گره</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation type="unfinished">باز کردن کنسول دی باگ و تشخیص گره</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">ادرس ارسال</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">ادرس درسافت</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI</source>
        <translation type="unfinished">بارک کردن یک بیت‌کوین: URI</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation type="unfinished">کیف پول را باز کنید
 </translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation type="unfinished">کیف پول را باز کنید
 </translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">کیف پول را ببندید</translation>
    </message>
    <message>
        <source>Restore Wallet…</source>
        <extracomment>Name of the menu item that restores wallet from a backup file.</extracomment>
        <translation type="unfinished">بازیابی کیف پول…</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">همه‌ی کیف پول‌ها را ببند</translation>
    </message>
    <message>
        <source>No wallets available</source>
        <translation type="unfinished">هیچ کیف پولی در دسترس نمی باشد</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">داده های کیف پول</translation>
    </message>
    <message>
        <source>Load Wallet Backup</source>
        <extracomment>The title for Restore Wallet File Windows</extracomment>
        <translation type="unfinished">بارگیری پشتیبان‌گیری کیف پول</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <extracomment>Label of the input field where the name of the wallet is entered.</extracomment>
        <translation type="unfinished">نام کیف پول</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">پنجره</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished">بزرگنمایی</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation type="unfinished">پنجره اصلی</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation type="unfinished">کلاینت: %1</translation>
    </message>
    <message>
        <source>&amp;Hide</source>
        <translation type="unfinished">مخفی کن</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform>%n اتصال(های) فعال به شبکه بیت کوین.</numerusform>
        </translation>
    </message>
    <message>
        <source>Click for more actions.</source>
        <extracomment>A substring of the tooltip. "More actions" are available via the context menu.</extracomment>
        <translation type="unfinished">برای عملیات‌های بیشتر کلیک کنید.</translation>
    </message>
    <message>
        <source>Show Peers tab</source>
        <extracomment>A context menu item. The "Peers tab" is an element of the "Node window".</extracomment>
        <translation type="unfinished">نمایش برگه همتایان </translation>
    </message>
    <message>
        <source>Disable network activity</source>
        <extracomment>A context menu item.</extracomment>
        <translation type="unfinished">غیرفعال‌سازی فعالیت شبکه</translation>
    </message>
    <message>
        <source>Enable network activity</source>
        <extracomment>A context menu item. The network activity was disabled previously.</extracomment>
        <translation type="unfinished">فعال‌سازی فعالیت شبکه</translation>
    </message>
    <message>
        <source>Pre-syncing Headers (%1%)…</source>
        <translation type="unfinished">پیش‌همگام‌سازی سرصفحه‌ها (%1%)…</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">خطا: %1</translation>
    </message>
    <message>
        <source>Private key &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">کلید خصوصی &lt;b&gt;غیر فعال &lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">بعد از احتساب کارمزد</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">تغییر</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation type="unfinished">(عدم)انتخاب همه</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation type="unfinished">حالت درختی</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation type="unfinished">حالت لیستی</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">میزان وجه:</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation type="unfinished">دریافت شده با برچسب</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation type="unfinished">دریافت شده با آدرس</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">تاریخ</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation type="unfinished">تاییدیه</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">تایید شده</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">کپی مقدار</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">تکثیر نشانی</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">تکثیر برچسب</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">روگرفت م&amp;قدار</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID and output index</source>
        <translation type="unfinished">شناسه و تراکنش و نمایه خروجی را کپی کنید</translation>
    </message>
    <message>
        <source>L&amp;ock unspent</source>
        <translation type="unfinished">قفل کردن خرج نشده ها</translation>
    </message>
    <message>
        <source>&amp;Unlock unspent</source>
        <translation type="unfinished">بازکردن قفل خرج نشده ها</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">کپی مقدار</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">کپی هزینه</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">کپی کردن بعد از احتساب کارمزد</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">کپی کردن بایت ها</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">کپی کردن تغییر</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation type="unfinished">(قفل شده است %1)</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(بدون لیبل)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation type="unfinished">تغییر از %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation type="unfinished">(تغییر)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation type="unfinished">ایجاد کیف پول
 </translation>
    </message>
    <message>
        <source>Creating Wallet &lt;b&gt;%1&lt;/b&gt;…</source>
        <extracomment>Descriptive text of the create wallet progress window which indicates to the user which wallet is currently being created.</extracomment>
        <translation type="unfinished">در حال ساخت کیف پول &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Create wallet failed</source>
        <translation type="unfinished">کیف پول "ایجاد" نشد
 </translation>
    </message>
    <message>
        <source>Create wallet warning</source>
        <translation type="unfinished">هشدار کیف پول ایجاد کنید
 </translation>
    </message>
    <message>
        <source>Can't list signers</source>
        <translation type="unfinished">نمی‌توان امضاکنندگان را فهرست کرد</translation>
    </message>
    <message>
        <source>Too many external signers found</source>
        <translation type="unfinished">تعداد زیادی امضاکننده خارجی پیدا شد</translation>
    </message>
</context>
<context>
    <name>LoadWalletsActivity</name>
    <message>
        <source>Load Wallets</source>
        <extracomment>Title of progress window which is displayed when wallets are being loaded.</extracomment>
        <translation type="unfinished">کیف پول ها را بارگیری کنید</translation>
    </message>
    <message>
        <source>Loading wallets…</source>
        <extracomment>Descriptive text of the load wallets progress window which indicates to the user that wallets are currently being loaded.</extracomment>
        <translation type="unfinished">در حال بارگیری کیف پول…</translation>
    </message>
</context>
<context>
    <name>MigrateWalletActivity</name>
    <message>
        <source>Watchonly scripts have been migrated to a new wallet named '%1'.</source>
        <translation type="unfinished">اسکریپت های Watchonly با موفقیت به کیف پول '%1' منتقل گردیدند.</translation>
    </message>
    <message>
        <source>Solvable but not watched scripts have been migrated to a new wallet named '%1'.</source>
        <translation type="unfinished">اسکریپت های قابل حل اما تماشا نشده به کیف پول جدیدی به نام "%1" منتقل شده اند.</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform>%n GB of space available</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform>(of %n GB needed)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform>(%n GB needed for full chain)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
        </translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Font in the Overview tab: </source>
        <translation type="unfinished">فونت در برگه کلی:</translation>
    </message>
    <message>
        <source>Options set in this dialog are overridden by the command line:</source>
        <translation type="unfinished">گزینه های تنظیم شده در این گفتگو توسط خط فرمان لغو می شوند:</translation>
    </message>
    <message>
        <source>Open Configuration File</source>
        <translation type="unfinished">بازکردن فایل پیکربندی</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation type="unfinished">تمام گزینه های مشتری را به طور پیش فرض بازنشانی کنید.
 </translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation type="unfinished">تنظیم مجدد گزینه ها</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation type="unfinished">شبکه</translation>
    </message>
    <message>
        <source>GB</source>
        <translation type="unfinished">گیگابایت</translation>
    </message>
    <message>
        <source>Reverting this setting requires re-downloading the entire blockchain.</source>
        <translation type="unfinished">برای برگرداندن این تنظیم نیاز به بارگیری مجدد کل بلاک چین است.</translation>
    </message>
    <message>
        <source>Accept connections from outside.</source>
        <translation type="unfinished">پذیرفتن اتصال شدن از بیرون</translation>
    </message>
    <message>
        <source>Allow incomin&amp;g connections</source>
        <translation type="unfinished">اجازه ورود و اتصالات</translation>
    </message>
    <message>
        <source>Connect to the Bitcoin network through a SOCKS5 proxy.</source>
        <translation type="unfinished">از طریق یک پروکسی SOCKS5 به شبکه بیت کوین متصل شوید.</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation type="unfinished">پراکسی و آی‌پی:</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation type="unfinished">پورت:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation type="unfinished">بندر پروکسی (به عنوان مثال 9050)
 </translation>
    </message>
    <message>
        <source>Used for reaching peers via:</source>
        <translation type="unfinished">برای دسترسی به همسالان از طریق:
 </translation>
    </message>
    <message>
        <source>Tor</source>
        <translation type="unfinished">شبکه Tor</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">پنجره</translation>
    </message>
    <message>
        <source>Show the icon in the system tray.</source>
        <translation type="unfinished">نمایش نمادک در سینی سامانه.</translation>
    </message>
    <message>
        <source>&amp;Show tray icon</source>
        <translation type="unfinished">نمایش نمادک سینی</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation type="unfinished">تنها بعد از کوچک کردن پنجره، tray icon را نشان بده.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation type="unfinished">&amp;کوچک کردن به سینی به‌جای نوار وظیفه</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation type="unfinished">کوچک کردن &amp;در زمان بسته شدن</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation type="unfinished">نمایش</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation type="unfinished">زبان واسط کاربری:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation type="unfinished">واحد نمایشگر مقادیر:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation type="unfinished">واحد تقسیم پیش فرض را برای نشان دادن در رابط کاربری و هنگام ارسال سکه انتخاب کنید.
 </translation>
    </message>
    <message>
        <source>Third-party URLs (e.g. a block explorer) that appear in the transactions tab as context menu items. %s in the URL is replaced by transaction hash. Multiple URLs are separated by vertical bar |.</source>
        <translation type="unfinished">نشانی‌های وب شخص ثالث (مانند کاوشگر بلوک) که در برگه تراکنش‌ها به عنوان آیتم‌های منوی زمینه ظاهر می‌شوند.  %s در URL با هش تراکنش جایگزین شده است.  چندین URL با نوار عمودی از هم جدا می شوند |.</translation>
    </message>
    <message>
        <source>&amp;Third-party transaction URLs</source>
        <translation type="unfinished">آدرس‌های اینترنتی تراکنش شخص ثالث</translation>
    </message>
    <message>
        <source>Whether to show coin control features or not.</source>
        <translation type="unfinished">آیا ویژگی های کنترل سکه را نشان می دهد یا خیر.
 </translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">تایید</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">لغو</translation>
    </message>
    <message>
        <source>Compiled without external signing support (required for external signing)</source>
        <extracomment>"External signing" means using devices such as hardware wallets.</extracomment>
        <translation type="unfinished">تدوین شده بدون حمایت از امضای خارجی (نیازمند امضای خارجی)</translation>
    </message>
    <message>
        <source>default</source>
        <translation type="unfinished">پیش فرض</translation>
    </message>
    <message>
        <source>none</source>
        <translation type="unfinished">خالی</translation>
    </message>
    <message>
        <source>Confirm options reset</source>
        <extracomment>Window title text of pop-up window shown when the user has chosen to reset options.</extracomment>
        <translation type="unfinished">باز نشانی گزینه ها را تأیید کنید
  </translation>
    </message>
    <message>
        <source>Client restart required to activate changes.</source>
        <extracomment>Text explaining that the settings changed will not come into effect until the client is restarted.</extracomment>
        <translation type="unfinished">کلاینت نیازمند ریست شدن است برای فعال کردن تغییرات</translation>
    </message>
    <message>
        <source>Current settings will be backed up at "%1".</source>
        <extracomment>Text explaining to the user that the client's current settings will be backed up at a specific location. %1 is a stand-in argument for the backup location's path.</extracomment>
        <translation type="unfinished">تنظیمات فعلی در "%1" پشتیبان گیری خواهد شد.</translation>
    </message>
    <message>
        <source>Client will be shut down. Do you want to proceed?</source>
        <extracomment>Text asking the user to confirm if they would like to proceed with a client shutdown.</extracomment>
        <translation type="unfinished">کلاینت خاموش خواهد شد.آیا میخواهید ادامه دهید؟</translation>
    </message>
    <message>
        <source>Configuration options</source>
        <extracomment>Window title text of pop-up box that allows opening up of configuration file.</extracomment>
        <translation type="unfinished">تنظیمات پیکربندی</translation>
    </message>
    <message>
        <source>The configuration file is used to specify advanced user options which override GUI settings. Additionally, any command-line options will override this configuration file.</source>
        <extracomment>Explanatory text about the priority order of instructions considered by client. The order from high to low being: command-line, configuration file, GUI settings.</extracomment>
        <translation type="unfinished">از پرونده پیکربندی برای انتخاب گزینه های کاربر پیشرفته استفاده می شود که تنظیمات ونک را نادیده می شود. بعلاوه ، هر گزینه خط فرمان این پرونده پیکربندی را لغو می کند. 

 </translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">ادامه</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">لغو</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">خطا</translation>
    </message>
    <message>
        <source>The configuration file could not be opened.</source>
        <translation type="unfinished">فایل پیکربندی قادر به بازشدن نبود.</translation>
    </message>
    <message>
        <source>This change would require a client restart.</source>
        <translation type="unfinished">تغییرات منوط به ریست کاربر است.</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation type="unfinished">آدرس پراکسی ارائه شده نامعتبر است.</translation>
    </message>
</context>
<context>
    <name>OptionsModel</name>
    <message>
        <source>Could not read setting "%1", %2.</source>
        <translation type="unfinished">نمی توان تنظیم "%1"، %2 را خواند.</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">فرم</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Bitcoin network after a connection is established, but this process has not completed yet.</source>
        <translation type="unfinished">اطلاعات نمایش داده شده ممکن است قدیمی باشد. کیف پول شما پس از برقراری اتصال به طور خودکار با شبکه Bitcoin همگام سازی می شود ، اما این روند هنوز کامل نشده است.
 </translation>
    </message>
    <message>
        <source>Watch-only:</source>
        <translation type="unfinished">فقط قابل-مشاهده:</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation type="unfinished">در دسترس:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation type="unfinished">موجودی قابل خرج در الان</translation>
    </message>
    <message>
        <source>Pending:</source>
        <translation type="unfinished">در حال انتظار:</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the spendable balance</source>
        <translation type="unfinished">تعداد تراکنشهایی که نیاز به تایید دارند و هنوز در مانده حساب جاری شما به حساب نیامده اند</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation type="unfinished">نارسیده:</translation>
    </message>
    <message>
        <source>Mined balance that has not yet matured</source>
        <translation type="unfinished">موجودی استخراج شده هنوز کامل نشده است</translation>
    </message>
    <message>
        <source>Balances</source>
        <translation type="unfinished">موجودی ها</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation type="unfinished">کل:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation type="unfinished">موجودی شما در همین لحظه</translation>
    </message>
    <message>
        <source>Your current balance in watch-only addresses</source>
        <translation type="unfinished">موجودی شما در همین لحظه در آدرس های Watch only Addresses</translation>
    </message>
    <message>
        <source>Spendable:</source>
        <translation type="unfinished">قابل مصرف:</translation>
    </message>
    <message>
        <source>Recent transactions</source>
        <translation type="unfinished">تراکنش های اخیر</translation>
    </message>
    <message>
        <source>Unconfirmed transactions to watch-only addresses</source>
        <translation type="unfinished">تراکنش های تایید نشده به آدرس های فقط قابل مشاهده watch-only</translation>
    </message>
    <message>
        <source>Mined balance in watch-only addresses that has not yet matured</source>
        <translation type="unfinished">موجودی استخراج شده در آدرس های فقط قابل مشاهده هنوز کامل نشده است</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Copy to Clipboard</source>
        <translation type="unfinished">کپی کردن</translation>
    </message>
    <message>
        <source>Save…</source>
        <translation type="unfinished">ذخیره ...</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished">بستن</translation>
    </message>
    <message>
        <source>Cannot sign inputs while wallet is locked.</source>
        <translation type="unfinished">وقتی کیف پول قفل است، نمی توان ورودی ها را امضا کرد.</translation>
    </message>
    <message>
        <source>Unknown error processing transaction.</source>
        <translation type="unfinished">مشکل نامشخصی در پردازش عملیات رخ داده.</translation>
    </message>
    <message>
        <source>Save Transaction Data</source>
        <translation type="unfinished">ذخیره اطلاعات عملیات</translation>
    </message>
    <message>
        <source>Partially Signed Transaction (Binary)</source>
        <extracomment>Expanded name of the binary PSBT file format. See: BIP 174.</extracomment>
        <translation type="unfinished">تراکنش نسبتا امضا شده (باینری)</translation>
    </message>
    <message>
        <source>Sends %1 to %2</source>
        <translation type="unfinished">%1را به %2 ارسال می کند</translation>
    </message>
    <message>
        <source>own address</source>
        <translation type="unfinished">آدرس خود</translation>
    </message>
    <message>
        <source>Total Amount</source>
        <translation type="unfinished">میزان کل</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">یا</translation>
    </message>
    <message>
        <source>Transaction has %1 unsigned inputs.</source>
        <translation type="unfinished">%1Transaction has  unsigned inputs.</translation>
    </message>
    <message>
        <source>Transaction still needs signature(s).</source>
        <translation type="unfinished">عملیات هنوز به امضا(ها) نیاز دارد.</translation>
    </message>
    <message>
        <source>(But no wallet is loaded.)</source>
        <translation type="unfinished">(اما هیچ کیف پولی بارگیری نمی شود.)</translation>
    </message>
    <message>
        <source>(But this wallet cannot sign transactions.)</source>
        <translation type="unfinished">(اما این کیف پول نمی تواند معاملات را امضا کند.)
 </translation>
    </message>
    <message>
        <source>(But this wallet does not have the right keys.)</source>
        <translation type="unfinished">(اما این کیف پول کلید درست را ندارد.)</translation>
    </message>
    <message>
        <source>Transaction status is unknown.</source>
        <translation type="unfinished">وضعیت عملیات نامشخص است.</translation>
    </message>
</context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>Payment request error</source>
        <translation type="unfinished">درخواست پرداخت با خطا مواجه شد</translation>
    </message>
    <message>
        <source>Cannot start bitcoin: click-to-pay handler</source>
        <translation type="unfinished">نمی توان بیت کوین را شروع کرد: کنترل کننده کلیک برای پرداخت
 </translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation type="unfinished">مدیریت URI</translation>
    </message>
    <message>
        <source>Cannot process payment request because BIP70 is not supported.
Due to widespread security flaws in BIP70 it's strongly recommended that any merchant instructions to switch wallets be ignored.
If you are receiving this error you should request the merchant provide a BIP21 compatible URI.</source>
        <translation type="unfinished">نمی توان درخواست پرداخت را پردازش کرد زیرا BIP70 پشتیبانی نمی شود. به دلیل نقص های امنیتی گسترده در BIP70، اکیداً توصیه می شود که هر دستورالعمل فروشنده برای تغییر کیف پول نادیده گرفته شود. اگر این خطا را دریافت می کنید، باید از فروشنده درخواست کنید که یک URI سازگار با BIP21 ارائه دهد.</translation>
    </message>
    <message>
        <source>Payment request file handling</source>
        <translation type="unfinished">درحال پردازش درخواست پرداخت</translation>
    </message>
</context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Ping</source>
        <extracomment>Title of Peers Table column which indicates the current latency of the connection with the peer.</extracomment>
        <translation type="unfinished">پینگ</translation>
    </message>
    <message>
        <source>Peer</source>
        <extracomment>Title of Peers Table column which contains a unique number used to identify a connection.</extracomment>
        <translation type="unfinished">همتا </translation>
    </message>
    <message>
        <source>Age</source>
        <extracomment>Title of Peers Table column which indicates the duration (length of time) since the peer connection started.</extracomment>
        <translation type="unfinished">سن</translation>
    </message>
    <message>
        <source>Direction</source>
        <extracomment>Title of Peers Table column which indicates the direction the peer connection was initiated from.</extracomment>
        <translation type="unfinished">مسیر</translation>
    </message>
    <message>
        <source>Sent</source>
        <extracomment>Title of Peers Table column which indicates the total amount of network information we have sent to the peer.</extracomment>
        <translation type="unfinished">فرستاده شد</translation>
    </message>
    <message>
        <source>Received</source>
        <extracomment>Title of Peers Table column which indicates the total amount of network information we have received from the peer.</extracomment>
        <translation type="unfinished">دریافتی</translation>
    </message>
    <message>
        <source>Type</source>
        <extracomment>Title of Peers Table column which describes the type of peer connection. The "type" describes why the connection exists.</extracomment>
        <translation type="unfinished">نوع</translation>
    </message>
    <message>
        <source>Network</source>
        <extracomment>Title of Peers Table column which states the network the peer connected through.</extracomment>
        <translation type="unfinished">شبکه</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Local Addresses</source>
        <translation type="unfinished">آدرس‌های محلی</translation>
    </message>
    <message>
        <source>Network addresses that your Bitcoin node is currently using to communicate with other nodes.</source>
        <translation type="unfinished">آدرس‌های شبکه ای که گره بیت کوین شما در حال حاضر از آنها برای ارتباط با گره های دیگر استفاده می کند.</translation>
    </message>
    <message>
        <source>Received</source>
        <translation type="unfinished">دریافتی</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation type="unfinished">فرستاده شد</translation>
    </message>
    <message>
        <source>Hide Peers Detail</source>
        <translation type="unfinished">پنهان کردن جزئیات همتایان</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation type="unfinished">کنترل+X</translation>
    </message>
    <message>
        <source>Last Transaction</source>
        <translation type="unfinished">اخرین تراکنش</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation type="unfinished">پنجره گره</translation>
    </message>
    <message>
        <source>Permissions</source>
        <translation type="unfinished">مجوزها</translation>
    </message>
    <message>
        <source>The BIP324 session ID string in hex.</source>
        <translation type="unfinished">رشته شناسه جلسه BIP324 به صورت هگز.</translation>
    </message>
    <message>
        <source>Connection Time</source>
        <translation type="unfinished">زمان اتصال</translation>
    </message>
    <message>
        <source>Last Block</source>
        <translation type="unfinished">بلاک اخیر</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation type="unfinished">ترافیک شبکه</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation type="unfinished">جمعا</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished">هیچ کدام</translation>
    </message>
    <message>
        <source>Node window - [%1]</source>
        <translation type="unfinished">پنجره گره - [%1]</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">روگرفت م&amp;قدار</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(برچسبی ندارد)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Change:</source>
        <translation type="unfinished">تغییر</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">کپی مقدار</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">کپی مقدار</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">کپی کردن بعد از احتساب کارمزد</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">کپی کردن تغییر</translation>
    </message>
    <message>
        <source>Save Transaction Data</source>
        <translation type="unfinished">ذخیره اطلاعات عملیات</translation>
    </message>
    <message>
        <source>Partially Signed Transaction (Binary)</source>
        <extracomment>Expanded name of the binary PSBT file format. See: BIP 174.</extracomment>
        <translation type="unfinished">تراکنش نسبتا امضا شده (باینری)</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">یا</translation>
    </message>
    <message>
        <source>%1 from wallet '%2'</source>
        <translation type="unfinished">%1 از کیف پول «%2»</translation>
    </message>
    <message>
        <source>Total Amount</source>
        <translation type="unfinished">میزان کل</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform>Estimated to begin confirmation within %n block(s).</numerusform>
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(برچسبی ندارد)</translation>
    </message>
</context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>You can sign messages/agreements with your legacy (P2PKH) addresses to prove you can receive bitcoins sent to them. Be careful not to sign anything vague or random, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation type="unfinished">می‌توانید پیام‌ها/توافق‌نامه‌هایی را با آدرس‌های قدیمی خود (P2PKH) امضا کنید تا ثابت کنید که می‌توانید بیت‌کوین‌های ارسال شده برای آنها را دریافت کنید. مراقب باشید هیچ چیز مبهم یا تصادفی را امضا نکنید، زیرا حملات فیشینگ ممکن است سعی کنند شما را فریب دهند تا با هویت خود آنها را امضا کنید. فقط اظهارات کاملاً مفصلی را که قابل قبول هستند را امضا کنید.</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>own address</source>
        <translation type="unfinished">آدرس خود</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform>matures in %n more block(s)</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 (Certificate was not verified)</source>
        <translation type="unfinished">%1 (گواهی تایید نشد)</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Type</source>
        <translation type="unfinished">نوع</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(برچسبی ندارد)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">روگرفت م&amp;قدار</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">نوع</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">کیف پول جدیدی ایجاد کنید
 </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">خطا</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">داده های موجود در برگه فعلی را به یک فایل صادر کنید</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">داده های کیف پول</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">لغو</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error: Unable to read wallet's best block locator record</source>
        <translation type="unfinished">خطا: خواندن بهترین سابقه یاب بلوک کیف پول امکان پذیر نیست</translation>
    </message>
    <message>
        <source>Error: Unable to write solvable wallet best block locator record</source>
        <translation type="unfinished">خطا: نوشتن بهترین سابقه یاب بلوک کیف پول قابل حل امکان پذیر نیست</translation>
    </message>
    <message>
        <source>Error: Unable to write watchonly wallet best block locator record</source>
        <translation type="unfinished">خطا: نوشتن بهترین سابقه بلوک یاب کیف پول فقط دیدنی امکان پذیر نیست</translation>
    </message>
    <message>
        <source>Error: database transaction cannot be executed for wallet %s</source>
        <translation type="unfinished">خطا: تراکنش پایگاه داده را نمی توان برای کیف پول اجرا کرد %s</translation>
    </message>
    <message>
        <source>Failure removing transaction: %s</source>
        <translation type="unfinished">عدم موفقیت در حذف تراکنش:%s</translation>
    </message>
    <message>
        <source>Transaction %s does not belong to this wallet</source>
        <translation type="unfinished">تراکنش %s به این کیف پول تعلق ندارد</translation>
    </message>
    <message>
        <source>Wallet file creation failed: %s</source>
        <translation type="unfinished">عدم موفقیت در ساخت فایل کیف پول: %s</translation>
    </message>
    <message>
        <source>Error: Could not add watchonly tx %s to watchonly wallet</source>
        <translation type="unfinished">خطا:‌ نشد تراکنش فقط قابل مشاهده %s به کیف پول فقط قابل مشاهده اضافه شود</translation>
    </message>
    <message>
        <source>Error: Could not delete watchonly transactions. </source>
        <translation type="unfinished">خطا: تراکنش های فقط دیدنی حذف نشد.</translation>
    </message>
    </context>
</TS>